==> ejc-budgetmanage-impl-3.0.0-20220325.144208-24-sources.jar: com/ejianc/business/record/bean/RecordestimatesummaryEntity.java <==
package com.ejianc.business.record.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 设计概算汇总变更记录
 * 
 * @author generator
 * 
 */
 @TableName("ejc_record_budgetmanage_budgetestimatesummary")
public class RecordestimatesummaryEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="budgetestimatesummary_code")
    private java.lang.String budgetestimatesummaryCode; // 变更记录编码
    @TableField(value="bill_code")
    private java.lang.String billCode; // 
    @TableField(value="budgetestimatesummary_id")
    private java.lang.Long budgetestimatesummaryId; // 设计概算汇总id
    @TableField(value="project_id")
    private java.lang.Long projectId; // 项目id
    @TableField(value="project_name")
    private java.lang.String projectName; // 项目名称
    @TableField(value="org_id")
    private java.lang.Long orgId; // 所属组织id
    @TableField(value="org_name")
    private java.lang.String orgName; // 所属组织名称
    @TableField(value="project_department_id")
    private java.lang.Long projectDepartmentId; // 项目部id
    @TableField(value="operator_id")
    private java.lang.Long operatorId; // 经办人id
    @TableField(value="operator_name")
    private java.lang.String operatorName; // 经办人名称
    @TableField(value="budget_estimate_total")
    private java.math.BigDecimal budgetEstimateTotal; // 设计概算合计
    @TableField(value="engineering_total")
    private java.math.BigDecimal engineeringTotal; // 建筑工程费合计
    @TableField(value="purchase_total")
    private java.math.BigDecimal purchaseTotal; // 设备购置费合计
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="change_reason")
    private java.lang.String changeReason; // 变更原因
    @TableField(value="effect_date")
    private java.util.Date effectDate; // 生效时间

    
    @TableField(exist=false)
    @SubEntity(serviceName="recordestsumdetailService", pidName = "recordMid")
    private List<RecordestsumdetailEntity> recordestsumdetailEntities = new ArrayList<>(); // 设计概算汇总变更记录子表
    

    /**
     * 变更记录编码
     */
    public java.lang.String getBudgetestimatesummaryCode() {
        return budgetestimatesummaryCode;
    }

    /**
     * 变更记录编码
     */
    public void setBudgetestimatesummaryCode(java.lang.String budgetestimatesummaryCode) {
        this.budgetestimatesummaryCode = budgetestimatesummaryCode;
    }
    /**
     * 
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 设计概算汇总id
     */
    public java.lang.Long getBudgetestimatesummaryId() {
        return budgetestimatesummaryId;
    }

    /**
     * 设计概算汇总id
     */
    public void setBudgetestimatesummaryId(java.lang.Long budgetestimatesummaryId) {
        this.budgetestimatesummaryId = budgetestimatesummaryId;
    }
    /**
     * 项目id
     */
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    public java.lang.Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    /**
     * 经办人id
     */
    public java.lang.Long getOperatorId() {
        return operatorId;
    }

    /**
     * 经办人id
     */
    public void setOperatorId(java.lang.Long operatorId) {
        this.operatorId = operatorId;
    }
    /**
     * 经办人名称
     */
    public java.lang.String getOperatorName() {
        return operatorName;
    }

    /**
     * 经办人名称
     */
    public void setOperatorName(java.lang.String operatorName) {
        this.operatorName = operatorName;
    }
    /**
     * 设计概算合计
     */
    public java.math.BigDecimal getBudgetEstimateTotal() {
        return budgetEstimateTotal;
    }

    /**
     * 设计概算合计
     */
    public void setBudgetEstimateTotal(java.math.BigDecimal budgetEstimateTotal) {
        this.budgetEstimateTotal = budgetEstimateTotal;
    }
    /**
     * 建筑工程费合计
     */
    public java.math.BigDecimal getEngineeringTotal() {
        return engineeringTotal;
    }

    /**
     * 建筑工程费合计
     */
    public void setEngineeringTotal(java.math.BigDecimal engineeringTotal) {
        this.engineeringTotal = engineeringTotal;
    }
    /**
     * 设备购置费合计
     */
    public java.math.BigDecimal getPurchaseTotal() {
        return purchaseTotal;
    }

    /**
     * 设备购置费合计
     */
    public void setPurchaseTotal(java.math.BigDecimal purchaseTotal) {
        this.purchaseTotal = purchaseTotal;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 变更原因
     */
    public java.lang.String getChangeReason() {
        return changeReason;
    }

    /**
     * 变更原因
     */
    public void setChangeReason(java.lang.String changeReason) {
        this.changeReason = changeReason;
    }
    /**
     * 生效时间
     */
    public java.util.Date getEffectDate() {
        return effectDate;
    }

    /**
     * 生效时间
     */
    public void setEffectDate(java.util.Date effectDate) {
        this.effectDate = effectDate;
    }
    
    /**
     * 设计概算汇总变更记录子表
     */
    public List<RecordestsumdetailEntity> getRecordestsumdetailEntities() {
        return recordestsumdetailEntities;
    }

    /**
     * 设计概算汇总变更记录子表
     */
    public void setRecordestsumdetailEntities(List<RecordestsumdetailEntity> recordestsumdetailEntities) {
        this.recordestsumdetailEntities = recordestsumdetailEntities;
    }
}

==> ejc-budgetmanage-impl-3.0.0-20230324.091733-161-sources.jar: com/ejianc/business/record/bean/RecordestimatesummaryEntity.java <==
package com.ejianc.business.record.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 设计概算汇总变更记录
 * 
 * @author generator
 * 
 */
 @TableName("ejc_record_budgetmanage_budgetestimatesummary")
public class RecordestimatesummaryEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="budgetestimatesummary_code")
    private java.lang.String budgetestimatesummaryCode; // 变更记录编码
    @TableField(value="bill_code")
    private java.lang.String billCode; // 
    @TableField(value="budgetestimatesummary_id")
    private java.lang.Long budgetestimatesummaryId; // 设计概算汇总id
    @TableField(value="project_id")
    private java.lang.Long projectId; // 项目id
    @TableField(value="project_name")
    private java.lang.String projectName; // 项目名称
    @TableField(value="org_id")
    private java.lang.Long orgId; // 所属组织id
    @TableField(value="org_name")
    private java.lang.String orgName; // 所属组织名称
    @TableField(value="project_department_id")
    private java.lang.Long projectDepartmentId; // 项目部id
    @TableField(value="operator_id")
    private java.lang.Long operatorId; // 经办人id
    @TableField(value="operator_name")
    private java.lang.String operatorName; // 经办人名称
    @TableField(value="budget_estimate_total")
    private java.math.BigDecimal budgetEstimateTotal; // 设计概算合计
    @TableField(value="engineering_total")
    private java.math.BigDecimal engineeringTotal; // 建筑工程费合计
    @TableField(value="purchase_total")
    private java.math.BigDecimal purchaseTotal; // 设备购置费合计
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="change_reason")
    private java.lang.String changeReason; // 变更原因
    @TableField(value="effect_date")
    private java.util.Date effectDate; // 生效时间

    
    @TableField(exist=false)
    @SubEntity(serviceName="recordestsumdetailService", pidName = "recordMid")
    private List<RecordestsumdetailEntity> estsumdetailEntities = new ArrayList<>(); // 设计概算汇总变更记录子表
    

    /**
     * 变更记录编码
     */
    public java.lang.String getBudgetestimatesummaryCode() {
        return budgetestimatesummaryCode;
    }

    /**
     * 变更记录编码
     */
    public void setBudgetestimatesummaryCode(java.lang.String budgetestimatesummaryCode) {
        this.budgetestimatesummaryCode = budgetestimatesummaryCode;
    }
    /**
     * 
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 设计概算汇总id
     */
    public java.lang.Long getBudgetestimatesummaryId() {
        return budgetestimatesummaryId;
    }

    /**
     * 设计概算汇总id
     */
    public void setBudgetestimatesummaryId(java.lang.Long budgetestimatesummaryId) {
        this.budgetestimatesummaryId = budgetestimatesummaryId;
    }
    /**
     * 项目id
     */
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    public java.lang.Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    /**
     * 经办人id
     */
    public java.lang.Long getOperatorId() {
        return operatorId;
    }

    /**
     * 经办人id
     */
    public void setOperatorId(java.lang.Long operatorId) {
        this.operatorId = operatorId;
    }
    /**
     * 经办人名称
     */
    public java.lang.String getOperatorName() {
        return operatorName;
    }

    /**
     * 经办人名称
     */
    public void setOperatorName(java.lang.String operatorName) {
        this.operatorName = operatorName;
    }
    /**
     * 设计概算合计
     */
    public java.math.BigDecimal getBudgetEstimateTotal() {
        return budgetEstimateTotal;
    }

    /**
     * 设计概算合计
     */
    public void setBudgetEstimateTotal(java.math.BigDecimal budgetEstimateTotal) {
        this.budgetEstimateTotal = budgetEstimateTotal;
    }
    /**
     * 建筑工程费合计
     */
    public java.math.BigDecimal getEngineeringTotal() {
        return engineeringTotal;
    }

    /**
     * 建筑工程费合计
     */
    public void setEngineeringTotal(java.math.BigDecimal engineeringTotal) {
        this.engineeringTotal = engineeringTotal;
    }
    /**
     * 设备购置费合计
     */
    public java.math.BigDecimal getPurchaseTotal() {
        return purchaseTotal;
    }

    /**
     * 设备购置费合计
     */
    public void setPurchaseTotal(java.math.BigDecimal purchaseTotal) {
        this.purchaseTotal = purchaseTotal;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 变更原因
     */
    public java.lang.String getChangeReason() {
        return changeReason;
    }

    /**
     * 变更原因
     */
    public void setChangeReason(java.lang.String changeReason) {
        this.changeReason = changeReason;
    }
    /**
     * 生效时间
     */
    public java.util.Date getEffectDate() {
        return effectDate;
    }

    /**
     * 生效时间
     */
    public void setEffectDate(java.util.Date effectDate) {
        this.effectDate = effectDate;
    }

    public List<RecordestsumdetailEntity> getEstsumdetailEntities() {
        return estsumdetailEntities;
    }

    public void setEstsumdetailEntities(List<RecordestsumdetailEntity> estsumdetailEntities) {
        this.estsumdetailEntities = estsumdetailEntities;
    }
}
